;; This is an operating system configuration generated
;; by the graphical installer.
;;
;; Once installation is complete, you can learn and modify
;; this file to tweak the system configuration, and pass it
;; to the 'guix system reconfigure' command to effect your
;; changes.


;; Indicate which modules to import to access the variables
;; used in this configuration.
(use-modules (gnu))
(use-service-modules cups desktop networking ssh xorg)

(operating-system
  (locale "en_US.utf8")
  (timezone "Asia/Tbilisi")
  (keyboard-layout (keyboard-layout "us,ru"
                                    #:options '("grp:shifts_toggle" "ctrl:nocaps")))
  (host-name "wkz-desktop")

  ;; The list of user accounts ('root' is implicit).
  (users (cons* (user-account
                  (name "w96k")
                  (comment "W96K")
                  (group "users")
                  (home-directory "/home/w96k")
                  (supplementary-groups '("wheel" "netdev" "audio" "video")))
                %base-user-accounts))

  ;; Packages installed system-wide.  Users can also install packages
  ;; under their own account: use 'guix search KEYWORD' to search
  ;; for packages and 'guix install PACKAGE' to install a package.
  (packages (append (list (specification->package "xterm")
                          (specification->package "emacs")
                          (specification->package "emacs-exwm")
			  (specification->package "emacs-guix")
			  (specification->package "git")
			  (specification->package "os-prober")
                          (specification->package
                           "emacs-desktop-environment")
                          (specification->package "nss-certs"))
                    %base-packages))

  ;; Below is the list of system services.  To search for available
  ;; services, run 'guix system search KEYWORD' in a terminal.
  (services
   (append (list
            (service openssh-service-type)
            (service tor-service-type)

	   

	   ;; (remove (lambda (service)
	   ;; 	     (eq? (service-kind service) gdm-service-type))
	   ;; 	   %desktop-services)

	   (service slim-service-type
		    (slim-configuration
		     (xorg-configuration
		      (xorg-configuration
		       (drivers '("modesetting"))
		       (keyboard-layout keyboard-layout))))))
	   
	   
	   (modify-services %desktop-services
			    (delete gdm-service-type))))

  (bootloader (bootloader-configuration
                (bootloader grub-efi-bootloader)
                (targets (list "/boot/efi"))
                (keyboard-layout keyboard-layout)
		(menu-entries
		 (list
		  (menu-entry
		   (label "Proprietary work system")
		   (linux "/boot/vmlinuz-6.2.0-32-generic")
		   (linux-arguments '("root=UUID=908bea86-3c60-4f30-a3b0-c224912bf4a9"))
		   ;; (linux-arguments '("root=(hd2,gpt2)"))
		   (device (uuid "908bea86-3c60-4f30-a3b0-c224912bf4a9" 'ext4))
		   (initrd "/boot/initrd.img-6.2.0-32-generic"))
		  ))))
  
  (mapped-devices (list (mapped-device
                          (source (uuid
                                   "fd9bdf14-371d-4767-90f4-5d51111a2329"))
                          (target "cryptroot")
                          (type luks-device-mapping))))

  ;; The list of file systems that get "mounted".  The unique
  ;; file system identifiers there ("UUIDs") can be obtained
  ;; by running 'blkid' in a terminal.
  (file-systems (cons* (file-system
                         (mount-point "/boot/efi")
                         (device (uuid "17C5-3E35"
                                       'fat32))
                         (type "vfat"))
                       (file-system
                         (mount-point "/")
                         (device "/dev/mapper/cryptroot")
                         (type "ext4")
                         (dependencies mapped-devices)) %base-file-systems)))
